@@ -46,13 +46,15 @@ def dump(table, ttFont=None):
 def diff_binary_fragments(font_bytes, expected_fragments):
     pos = 0
     prev_desc = ""
+    errors = 0
     for expected_bytes, description in expected_fragments:
         actual_bytes = font_bytes[pos : pos + len(expected_bytes)]
-        assert (
-            actual_bytes == expected_bytes
-        ), f'{description} (previous "{prev_desc}", bytes: {str(font_bytes[pos:pos+16])}'
+        if actual_bytes != expected_bytes:
+            print(f'{description} (previous "{prev_desc}", actual_bytes: {"".join("%02x" % v for v in actual_bytes)} bytes: {str(font_bytes[pos:pos+16])}')
+            errors += 1
         pos += len(expected_bytes)
         prev_desc = description
+    assert errors == 0
     assert pos == len(
         font_bytes
     ), f"Leftover font bytes, used {pos} of {len(font_bytes)}"
@@ -106,156 +108,175 @@ COLR_V1_SAMPLE = (
     (b"\x00\x00\x00 ", "Offset to LayerRecordArray from beginning of table (32)"),
     (b"\x00\x03", "LayerRecordCount (3)"),
     (b"\x00\x00\x00,", "Offset to BaseGlyphV1List from beginning of table (44)"),
-    (b"\x00\x00\x00\x81", "Offset to LayerV1List from beginning of table (129)"),
+    (b"\x00\x00\x00\xac", "Offset to LayerV1List from beginning of table (172)"),
     (b"\x00\x00\x00\x00", "Offset to VarStore (NULL)"),
     (b"\x00\x06", "BaseGlyphRecord[0].BaseGlyph (6)"),
     (b"\x00\x00", "BaseGlyphRecord[0].FirstLayerIndex (0)"),
-    (b"\x00\x04", "BaseGlyphRecord[0].NumLayers (4)"),
+    (b"\x00\x03", "BaseGlyphRecord[0].NumLayers (3)"),
     (b"\x00\x07", "LayerRecord[0].LayerGlyph (7)"),
     (b"\x00\x00", "LayerRecord[0].PaletteIndex (0)"),
     (b"\x00\x08", "LayerRecord[1].LayerGlyph (8)"),
     (b"\x00\x01", "LayerRecord[1].PaletteIndex (1)"),
     (b"\x00\t", "LayerRecord[2].LayerGlyph (9)"),
     (b"\x00\x02", "LayerRecord[2].PaletteIndex (2)"),
-    (b"\x00\x00\x00\x02", "BaseGlyphV1List.BaseGlyphCount (2)"),
+    # BaseGlyphV1List
+    (b"\x00\x00\x00\x03", "BaseGlyphV1List.BaseGlyphCount (3)"),
     (b"\x00\n", "BaseGlyphV1List.BaseGlyphV1Record[0].BaseGlyph (10)"),
-    (
-        b"\x00\x00\x00\x10",
-        "Offset to Paint table from beginning of BaseGlyphV1List (16)",
-    ),
-    (b"\x00\x0e", "BaseGlyphV1List.BaseGlyphV1Record[1].BaseGlyph (14)"),
     (
         b"\x00\x00\x00\x16",
         "Offset to Paint table from beginning of BaseGlyphV1List (22)",
     ),
+    (b"\x00\x0e", "BaseGlyphV1List.BaseGlyphV1Record[1].BaseGlyph (14)"),
+    (
+        b"\x00\x00\x00\x1c",
+        "Offset to Paint table from beginning of BaseGlyphV1List (28)",
+    ),
+    (b"\x00\x0f", "BaseGlyphV1List.BaseGlyphV1Record[2].BaseGlyph (15)"),
+    (
+        b"\x00\x00\x00\x5b",
+        "Offset to Paint table from beginning of BaseGlyphV1List (91)",
+    ),
+    # BaseGlyphV1Record[0]
     (b"\x01", "BaseGlyphV1Record[0].Paint.Format (1)"),
     (b"\x04", "BaseGlyphV1Record[0].Paint.NumLayers (4)"),
     (b"\x00\x00\x00\x00", "BaseGlyphV1Record[0].Paint.FirstLayerIndex (0)"),
-    (b"\x0B", "BaseGlyphV1Record[1].Paint.Format (11)"),
+    # BaseGlyphV1Record[1]
+    (b"\x14", "BaseGlyphV1Record[1].Paint.Format (20)"),
     (b"\x00\x00<", "Offset to SourcePaint from beginning of PaintComposite (60)"),
     (b"\x03", "BaseGlyphV1Record[1].Paint.CompositeMode [SRC_OVER] (3)"),
     (b"\x00\x00\x08", "Offset to BackdropPaint from beginning of PaintComposite (8)"),
-    (b"\x07", "BaseGlyphV1Record[1].Paint.BackdropPaint.Format (7)"),
-    (b"\x00\x00\x34", "Offset to Paint from beginning of PaintTransform (52)"),
-    (b"\x00\x01\x00\x00\x00\x00\x00\x00", "Affine2x3.xx.value (1.0)"),
-    (b"\x00\x00\x00\x00\x00\x00\x00\x00", "Affine2x3.xy.value (0.0)"),
-    (b"\x00\x00\x00\x00\x00\x00\x00\x00", "Affine2x3.yx.value (0.0)"),
-    (b"\x00\x01\x00\x00\x00\x00\x00\x00", "Affine2x3.yy.value (1.0)"),
-    (b"\x01\x2c\x00\x00\x00\x00\x00\x00", "Affine2x3.dx.value (300.0)"),
-    (b"\x00\x00\x00\x00\x00\x00\x00\x00", "Affine2x3.dy.value (0.0)"),
-    (b"\x06", "BaseGlyphV1Record[1].Paint.SourcePaint.Format (6)"),
+    (b"\x0d", "BaseGlyphV1Record[1].Paint.BackdropPaint.Format (13)"),
+    (b"\x00\x00\x34", "Offset to Paint from beginning of PaintVarTransform (52)"),
+    (b"\x00\x01\x00\x00\xff\xff\xff\xff", "Affine2x3.xx.value (1.0)"),
+    (b"\x00\x00\x00\x00\xff\xff\xff\xff", "Affine2x3.xy.value (0.0)"),
+    (b"\x00\x00\x00\x00\xff\xff\xff\xff", "Affine2x3.yx.value (0.0)"),
+    (b"\x00\x01\x00\x00\xff\xff\xff\xff", "Affine2x3.yy.value (1.0)"),
+    (b"\x01\x2c\x00\x00\xff\xff\xff\xff", "Affine2x3.dx.value (300.0)"),
+    (b"\x00\x00\x00\x00\xff\xff\xff\xff", "Affine2x3.dy.value (0.0)"),
+    (b"\x0b", "BaseGlyphV1Record[1].Paint.SourcePaint.Format (11)"),
     (b"\x00\n", "BaseGlyphV1Record[1].Paint.SourcePaint.Glyph (10)"),
+    # BaseGlyphV1Record[2]
+    (b"\x0a", "BaseGlyphV1Record[2].Paint.Format (10)"),
+    (b"\x00\x00\x06", "Offset to Paint subtable from beginning of PaintGlyph (6)"),
+    (b"\x00\x0b", "BaseGlyphV1Record[2].Paint.Glyph (11)"),
+    (b"\x08", "BaseGlyphV1Record[2].Paint.Paint.Format (8)"),
+    (b"\x00\x00\x10", "Offset to ColorLine from beginning of PaintSweepGradient (16)"),
+    (b"\x01\x03", "centerX (259)"),
+    (b"\x01\x2c", "centerY (300)"),
+    (b"\x00\x2d\x00\x00", "startAngle (45.0)"),
+    (b"\x00\x87\x00\x00", "endAngle (135.0)"),
+    (b"\x00", "ColorLine.Extend (0; pad)"),
+    (b"\x00\x02", "ColorLine.StopCount (2)"),
+    (b"\x00\x00", "ColorLine.ColorStop[0].StopOffset (0.0)"),
+    (b"\x00\x03", "ColorLine.ColorStop[0].Color.PaletteIndex (3)"),
+    (b"@\x00", "ColorLine.ColorStop[0].Color.Alpha (1.0)"),
+    (b"@\x00", "ColorLine.ColorStop[1].StopOffset (1.0)"),
+    (b"\x00\x05", "ColorLine.ColorStop[1].Color.PaletteIndex (5)"),
+    (b"@\x00", "ColorLine.ColorStop[1].Color.Alpha (1.0)"),
+    # LayerV1List
     (b"\x00\x00\x00\x04", "LayerV1List.LayerCount (4)"),
     (
         b"\x00\x00\x00\x14",
         "First Offset to Paint table from beginning of LayerV1List (20)",
     ),
     (
-        b"\x00\x00\x00\x1a",
-        "Second Offset to Paint table from beginning of LayerV1List (26)",
+        b"\x00\x00\x00\x23",
+        "Second Offset to Paint table from beginning of LayerV1List (35)",
     ),
     (
-        b"\x00\x00\x00u",
-        "Third Offset to Paint table from beginning of LayerV1List (117)",
+        b"\x00\x00\x00\x4e",
+        "Third Offset to Paint table from beginning of LayerV1List (78)",
     ),
     (
-        b"\x00\x00\x00\xf6",
-        "Fourth Offset to Paint table from beginning of LayerV1List (246)",
+        b"\x00\x00\x00\xb7",
+        "Fourth Offset to Paint table from beginning of LayerV1List (183)",
     ),
     # PaintGlyph glyph00011
-    (b"\x05", "LayerV1List.Paint[0].Format (5)"),
-    (b"\x00\x01<", "Offset24 to Paint subtable from beginning of PaintGlyph (316)"),
+    (b"\x0a", "LayerV1List.Paint[0].Format (10)"),
+    (b"\x00\x00\x06", "Offset24 to Paint subtable from beginning of PaintGlyph (6)"),
     (b"\x00\x0b", "LayerV1List.Paint[0].Glyph (glyph00011)"),
+    # PaintVarSolid
+    (b"\x03", "LayerV1List.Paint[0].Paint.Format (3)"),
+    (b"\x00\x02", "Paint.Color.PaletteIndex (2)"),
+    (b" \x00", "Paint.Color.Alpha.value (0.5)"),
+    (b"\xff\xff\xff\xff", "Paint.Color.Alpha.varIdx (0xFFFFFFFF)"),
     # PaintGlyph glyph00012
-    (b"\x05", "LayerV1List.Paint[1].Format (5)"),
+    (b"\x0a", "LayerV1List.Paint[1].Format (10)"),
     (b"\x00\x00\x06", "Offset to Paint subtable from beginning of PaintGlyph (6)"),
     (b"\x00\x0c", "LayerV1List.Paint[1].Glyph (glyph00012)"),
-    (b"\x03", "LayerV1List.Paint[1].Paint.Format (3)"),
-    (b"\x00\x00(", "Offset to ColorLine from beginning of PaintLinearGradient (40)"),
-    (b"\x00\x01", "Paint.x0.value (1)"),
-    (b"\x00\x00\x00\x00", "Paint.x0.varIdx (0)"),
-    (b"\x00\x02", "Paint.y0.value (2)"),
-    (b"\x00\x00\x00\x00", "Paint.y0.varIdx (0)"),
-    (b"\xff\xfd", "Paint.x1.value (-3)"),
-    (b"\x00\x00\x00\x00", "Paint.x1.varIdx (0)"),
-    (b"\xff\xfc", "Paint.y1.value (-4)"),
-    (b"\x00\x00\x00\x00", "Paint.y1.varIdx (0)"),
-    (b"\x00\x05", "Paint.x2.value (5)"),
-    (b"\x00\x00\x00\x00", "Paint.x2.varIdx (0)"),
-    (b"\x00\x06", "Paint.y2.value (6)"),
-    (b"\x00\x00\x00\x00", "Paint.y2.varIdx (0)"),
+    (b"\x04", "LayerV1List.Paint[1].Paint.Format (4)"),
+    (b"\x00\x00\x10", "Offset to ColorLine from beginning of PaintLinearGradient (16)"),
+    (b"\x00\x01", "Paint.x0 (1)"),
+    (b"\x00\x02", "Paint.y0 (2)"),
+    (b"\xff\xfd", "Paint.x1 (-3)"),
+    (b"\xff\xfc", "Paint.y1 (-4)"),
+    (b"\x00\x05", "Paint.x2 (5)"),
+    (b"\x00\x06", "Paint.y2 (6)"),
     (b"\x01", "ColorLine.Extend (1; repeat)"),
     (b"\x00\x03", "ColorLine.StopCount (3)"),
-    (b"\x00\x00", "ColorLine.ColorStop[0].StopOffset.value (0.0)"),
-    (b"\x00\x00\x00\x00", "ColorLine.ColorStop[0].StopOffset.varIdx (0)"),
+    (b"\x00\x00", "ColorLine.ColorStop[0].StopOffset (0.0)"),
     (b"\x00\x03", "ColorLine.ColorStop[0].Color.PaletteIndex (3)"),
-    (b"@\x00", "ColorLine.ColorStop[0].Color.Alpha.value (1.0)"),
-    (b"\x00\x00\x00\x00", "ColorLine.ColorStop[0].Color.Alpha.varIdx (0)"),
-    (b" \x00", "ColorLine.ColorStop[1].StopOffset.value (0.5)"),
-    (b"\x00\x00\x00\x00", "ColorLine.ColorStop[1].StopOffset.varIdx (0)"),
+    (b"@\x00", "ColorLine.ColorStop[0].Color.Alpha (1.0)"),
+    (b" \x00", "ColorLine.ColorStop[1].StopOffset (0.5)"),
     (b"\x00\x04", "ColorLine.ColorStop[1].Color.PaletteIndex (4)"),
-    (b"@\x00", "ColorLine.ColorStop[1].Color.Alpha.value (1.0)"),
-    (b"\x00\x00\x00\x00", "ColorLine.ColorStop[1].Color.Alpha.varIdx (0)"),
-    (b"@\x00", "ColorLine.ColorStop[2].StopOffset.value (1.0)"),
-    (b"\x00\x00\x00\x00", "ColorLine.ColorStop[2].StopOffset.varIdx (0)"),
+    (b"@\x00", "ColorLine.ColorStop[1].Color.Alpha (1.0)"),
+    (b"@\x00", "ColorLine.ColorStop[2].StopOffset (1.0)"),
     (b"\x00\x05", "ColorLine.ColorStop[2].Color.PaletteIndex (5)"),
-    (b"@\x00", "ColorLine.ColorStop[2].Color.Alpha.value (1.0)"),
-    (b"\x00\x00\x00\x00", "ColorLine.ColorStop[2].Color.Alpha.varIdx (0)"),
+    (b"@\x00", "ColorLine.ColorStop[2].Color.Alpha (1.0)"),
     # PaintGlyph glyph00013
-    (b"\x05", "LayerV1List.Paint[2].Format (5)"),
+    (b"\x0a", "LayerV1List.Paint[2].Format (10)"),
     (b"\x00\x00\x06", "Offset to Paint subtable from beginning of PaintGlyph (6)"),
     (b"\x00\r", "LayerV1List.Paint[2].Glyph (13)"),
-    (b"\x07", "LayerV1List.Paint[2].Paint.Format (5)"),
-    (b"\x00\x00\x34", "Offset to Paint subtable from beginning of PaintTransform (52)"),
-    (b"\xff\xf3\x00\x00\x00\x00\x00\x00", "Affine2x3.xx.value (-13)"),
-    (b"\x00\x0e\x00\x00\x00\x00\x00\x00", "Affine2x3.xy.value (14)"),
-    (b"\x00\x0f\x00\x00\x00\x00\x00\x00", "Affine2x3.yx.value (15)"),
-    (b"\xff\xef\x00\x00\x00\x00\x00\x00", "Affine2x3.yy.value (-17)"),
-    (b"\x00\x12\x00\x00\x00\x00\x00\x00", "Affine2x3.yy.value (18)"),
-    (b"\x00\x13\x00\x00\x00\x00\x00\x00", "Affine2x3.yy.value (19)"),
-    (b"\x04", "LayerV1List.Paint[2].Paint.Paint.Format (4)"),
-    (b"\x00\x00(", "Offset to ColorLine from beginning of PaintRadialGradient (40)"),
-    (b"\x00\x07\x00\x00\x00\x00", "Paint.x0.value (7)"),
-    (b"\x00\x08\x00\x00\x00\x00", "Paint.y0.value (8)"),
-    (b"\x00\t\x00\x00\x00\x00", "Paint.r0.value (9)"),
-    (b"\x00\n\x00\x00\x00\x00", "Paint.x1.value (10)"),
-    (b"\x00\x0b\x00\x00\x00\x00", "Paint.y1.value (11)"),
-    (b"\x00\x0c\x00\x00\x00\x00", "Paint.r1.value (12)"),
+    (b"\x0c", "LayerV1List.Paint[2].Paint.Format (12)"),
+    (b"\x00\x00\x1c", "Offset to Paint subtable from beginning of PaintTransform (28)"),
+    (b"\xff\xf3\x00\x00", "Affine2x3.xx (-13)"),
+    (b"\x00\x0e\x00\x00", "Affine2x3.xy (14)"),
+    (b"\x00\x0f\x00\x00", "Affine2x3.yx (15)"),
+    (b"\xff\xef\x00\x00", "Affine2x3.yy (-17)"),
+    (b"\x00\x12\x00\x00", "Affine2x3.yy (18)"),
+    (b"\x00\x13\x00\x00", "Affine2x3.yy (19)"),
+    (b"\x07", "LayerV1List.Paint[2].Paint.Paint.Format (7)"),
+    (b"\x00\x00(", "Offset to ColorLine from beginning of PaintVarRadialGradient (40)"),
+    (b"\x00\x07\xff\xff\xff\xff", "Paint.x0.value (7)"),
+    (b"\x00\x08\xff\xff\xff\xff", "Paint.y0.value (8)"),
+    (b"\x00\t\xff\xff\xff\xff", "Paint.r0.value (9)"),
+    (b"\x00\n\xff\xff\xff\xff", "Paint.x1.value (10)"),
+    (b"\x00\x0b\xff\xff\xff\xff", "Paint.y1.value (11)"),
+    (b"\x00\x0c\xff\xff\xff\xff", "Paint.r1.value (12)"),
     (b"\x00", "ColorLine.Extend (0; pad)"),
     (b"\x00\x02", "ColorLine.StopCount (2)"),
-    (b"\x00\x00\x00\x00\x00\x00", "ColorLine.ColorStop[0].StopOffset.value (0.0)"),
+    (b"\x00\x00\xff\xff\xff\xff", "ColorLine.ColorStop[0].StopOffset.value (0.0)"),
     (b"\x00\x06", "ColorLine.ColorStop[0].Color.PaletteIndex (6)"),
-    (b"@\x00\x00\x00\x00\x00", "ColorLine.ColorStop[0].Color.Alpha.value (1.0)"),
-    (b"@\x00\x00\x00\x00\x00", "ColorLine.ColorStop[1].StopOffset.value (1.0)"),
+    (b"@\x00\xff\xff\xff\xff", "ColorLine.ColorStop[0].Color.Alpha.value (1.0)"),
+    (b"@\x00\xff\xff\xff\xff", "ColorLine.ColorStop[1].StopOffset.value (1.0)"),
     (b"\x00\x07", "ColorLine.ColorStop[1].Color.PaletteIndex (7)"),
-    (b"\x19\x9a\x00\x00\x00\x00", "ColorLine.ColorStop[1].Color.Alpha.value (0.4)"),
+    (b"\x19\x9a\xff\xff\xff\xff", "ColorLine.ColorStop[1].Color.Alpha.value (0.4)"),
     # PaintTranslate
-    (b"\x08", "LayerV1List.Paint[3].Format (8)"),
-    (b"\x00\x00\x14", "Offset to Paint subtable from beginning of PaintTranslate (20)"),
-    (b"\x01\x01\x00\x00\x00\x00\x00\x00", "dx.value (257)"),
-    (b"\x01\x02\x00\x00\x00\x00\x00\x00", "dy.value (258)"),
+    (b"\x0e", "LayerV1List.Paint[3].Format (14)"),
+    (b"\x00\x00\x0c", "Offset to Paint subtable from beginning of PaintTranslate (12)"),
+    (b"\x01\x01\x00\x00", "dx (257)"),
+    (b"\x01\x02\x00\x00", "dy (258)"),
     # PaintRotate
-    (b"\x09", "LayerV1List.Paint[3].Paint.Format (9)"),
-    (b"\x00\x00\x1c", "Offset to Paint subtable from beginning of PaintRotate (28)"),
-    (b"\x00\x2d\x00\x00\x00\x00\x00\x00", "angle.value (45)"),
-    (b"\x00\xff\x00\x00\x00\x00\x00\x00", "centerX.value (255)"),
-    (b"\x01\x00\x00\x00\x00\x00\x00\x00", "centerY.value (256)"),
+    (b"\x10", "LayerV1List.Paint[3].Paint.Format (16)"),
+    (b"\x00\x00\x10", "Offset to Paint subtable from beginning of PaintRotate (16)"),
+    (b"\x00\x2d\x00\x00", "angle (45)"),
+    (b"\x00\xff\x00\x00", "centerX (255)"),
+    (b"\x01\x00\x00\x00", "centerY (256)"),
     # PaintSkew
-    (b"\x0a", "LayerV1List.Paint[3].Paint.Paint.Format (10)"),
-    (b"\x00\x00\x24", "Offset to Paint subtable from beginning of PaintSkew (36)"),
-    (b"\xff\xf5\x00\x00\x00\x00\x00\x00", "xSkewAngle (-11)"),
-    (b"\x00\x05\x00\x00\x00\x00\x00\x00", "ySkewAngle (5)"),
-    (b"\x00\xfd\x00\x00\x00\x00\x00\x00", "centerX.value (253)"),
-    (b"\x00\xfe\x00\x00\x00\x00\x00\x00", "centerY.value (254)"),
+    (b"\x12", "LayerV1List.Paint[3].Paint.Paint.Format (18)"),
+    (b"\x00\x00\x14", "Offset to Paint subtable from beginning of PaintSkew (20)"),
+    (b"\xff\xf5\x00\x00", "xSkewAngle (-11)"),
+    (b"\x00\x05\x00\x00", "ySkewAngle (5)"),
+    (b"\x00\xfd\x00\x00", "centerX.value (253)"),
+    (b"\x00\xfe\x00\x00", "centerY.value (254)"),
     # PaintGlyph
-    (b"\x05", "LayerV1List.Paint[2].Format (5)"),
+    (b"\x0a", "LayerV1List.Paint[3].Paint.Paint.Paint.Format (10)"),
     (b"\x00\x00\x06", "Offset to Paint subtable from beginning of PaintGlyph (6)"),
     (b"\x00\x0b", "LayerV1List.Paint[2].Glyph (11)"),
     # PaintSolid
-    (b"\x02", "LayerV1List.Paint[0].Paint.Format (2)"),
+    (b"\x02", "LayerV1List.Paint[0].Paint.Paint.Paint.Paint.Format (2)"),
     (b"\x00\x02", "Paint.Color.PaletteIndex (2)"),
-    (b" \x00", "Paint.Color.Alpha.value (0.5)"),
-    (b"\x00\x00\x00\x00", "Paint.Color.Alpha.varIdx (0)"),
+    (b" \x00", "Paint.Color.Alpha (0.5)"),
 )
 
 COLR_V1_DATA = b"".join(t[0] for t in COLR_V1_SAMPLE)
@@ -267,7 +288,7 @@ COLR_V1_XML = [
     '  <BaseGlyphRecord index="0">',
     '    <BaseGlyph value="glyph00006"/>',
     '    <FirstLayerIndex value="0"/>',
-    '    <NumLayers value="4"/>',
+    '    <NumLayers value="3"/>',
     "  </BaseGlyphRecord>",
     "</BaseGlyphRecordArray>",
     "<LayerRecordArray>",
@@ -286,7 +307,7 @@ COLR_V1_XML = [
     "</LayerRecordArray>",
     "<!-- LayerRecordCount=3 -->",
     "<BaseGlyphV1List>",
-    "  <!-- BaseGlyphCount=2 -->",
+    "  <!-- BaseGlyphCount=3 -->",
     '  <BaseGlyphV1Record index="0">',
     '    <BaseGlyph value="glyph00010"/>',
     '    <Paint Format="1"><!-- PaintColrLayers -->',
@@ -296,13 +317,13 @@ COLR_V1_XML = [
     "  </BaseGlyphV1Record>",
     '  <BaseGlyphV1Record index="1">',
     '    <BaseGlyph value="glyph00014"/>',
-    '    <Paint Format="11"><!-- PaintComposite -->',
-    '      <SourcePaint Format="6"><!-- PaintColrGlyph -->',
+    '    <Paint Format="20"><!-- PaintComposite -->',
+    '      <SourcePaint Format="11"><!-- PaintColrGlyph -->',
     '        <Glyph value="glyph00010"/>',
     "      </SourcePaint>",
     '      <CompositeMode value="src_over"/>',
-    '      <BackdropPaint Format="7"><!-- PaintTransform -->',
-    '        <Paint Format="6"><!-- PaintColrGlyph -->',
+    '      <BackdropPaint Format="13"><!-- PaintVarTransform -->',
+    '        <Paint Format="11"><!-- PaintColrGlyph -->',
     '          <Glyph value="glyph00010"/>',
     "        </Paint>",
     "        <Transform>",
@@ -316,11 +337,41 @@ COLR_V1_XML = [
     "      </BackdropPaint>",
     "    </Paint>",
     "  </BaseGlyphV1Record>",
+    '  <BaseGlyphV1Record index="2">',
+    '    <BaseGlyph value="glyph00015"/>',
+    '    <Paint Format="10"><!-- PaintGlyph -->',
+    '      <Paint Format="8"><!-- PaintSweepGradient -->',
+    "        <ColorLine>",
+    '          <Extend value="pad"/>',
+    "          <!-- StopCount=2 -->",
+    '          <ColorStop index="0">',
+    '            <StopOffset value="0.0"/>',
+    "            <Color>",
+    '              <PaletteIndex value="3"/>',
+    '              <Alpha value="1.0"/>',
+    "            </Color>",
+    "          </ColorStop>",
+    '          <ColorStop index="1">',
+    '            <StopOffset value="1.0"/>',
+    "            <Color>",
+    '              <PaletteIndex value="5"/>',
+    '              <Alpha value="1.0"/>',
+    "            </Color>",
+    "          </ColorStop>",
+    "        </ColorLine>",
+    '        <centerX value="259"/>',
+    '        <centerY value="300"/>',
+    '        <startAngle value="45.0"/>',
+    '        <endAngle value="135.0"/>',
+    "      </Paint>",
+    '      <Glyph value="glyph00011"/>',
+    "    </Paint>",
+    "  </BaseGlyphV1Record>",
     "</BaseGlyphV1List>",
     "<LayerV1List>",
     "  <!-- LayerCount=4 -->",
-    '  <Paint index="0" Format="5"><!-- PaintGlyph -->',
-    '    <Paint Format="2"><!-- PaintSolid -->',
+    '  <Paint index="0" Format="10"><!-- PaintGlyph -->',
+    '    <Paint Format="3"><!-- PaintVarSolid -->',
     "      <Color>",
     '        <PaletteIndex value="2"/>',
     '        <Alpha value="0.5"/>',
@@ -328,8 +379,8 @@ COLR_V1_XML = [
     "    </Paint>",
     '    <Glyph value="glyph00011"/>',
     "  </Paint>",
-    '  <Paint index="1" Format="5"><!-- PaintGlyph -->',
-    '    <Paint Format="3"><!-- PaintLinearGradient -->',
+    '  <Paint index="1" Format="10"><!-- PaintGlyph -->',
+    '    <Paint Format="4"><!-- PaintLinearGradient -->',
     "      <ColorLine>",
     '        <Extend value="repeat"/>',
     "        <!-- StopCount=3 -->",
@@ -364,9 +415,9 @@ COLR_V1_XML = [
     "    </Paint>",
     '    <Glyph value="glyph00012"/>',
     "  </Paint>",
-    '  <Paint index="2" Format="5"><!-- PaintGlyph -->',
-    '    <Paint Format="7"><!-- PaintTransform -->',
-    '      <Paint Format="4"><!-- PaintRadialGradient -->',
+    '  <Paint index="2" Format="10"><!-- PaintGlyph -->',
+    '    <Paint Format="12"><!-- PaintTransform -->',
+    '      <Paint Format="7"><!-- PaintVarRadialGradient -->',
     "        <ColorLine>",
     '          <Extend value="pad"/>',
     "          <!-- StopCount=2 -->",
@@ -403,10 +454,10 @@ COLR_V1_XML = [
     "    </Paint>",
     '    <Glyph value="glyph00013"/>',
     "  </Paint>",
-    '  <Paint index="3" Format="8"><!-- PaintTranslate -->',
-    '    <Paint Format="9"><!-- PaintRotate -->',
-    '      <Paint Format="10"><!-- PaintSkew -->',
-    '        <Paint Format="5"><!-- PaintGlyph -->',
+    '  <Paint index="3" Format="14"><!-- PaintTranslate -->',
+    '    <Paint Format="16"><!-- PaintRotate -->',
+    '      <Paint Format="18"><!-- PaintSkew -->',
+    '        <Paint Format="10"><!-- PaintGlyph -->',
     '          <Paint Format="2"><!-- PaintSolid -->',
     "            <Color>",
     '              <PaletteIndex value="2"/>',
