@@ -1,10 +1,9 @@
-# coding: utf-8
-from fontTools.misc.py23 import *
 from fontTools.misc.testTools import getXML, parseXML, FakeFont
 from fontTools.misc.textTools import deHexStr, hexStr
 from fontTools.misc.xmlWriter import XMLWriter
 from fontTools.ttLib.tables.otBase import OTTableReader, OTTableWriter
 import fontTools.ttLib.tables.otTables as otTables
+from io import StringIO
 import unittest
 
 
@@ -169,7 +168,7 @@ class MultipleSubstTest(unittest.TestCase):
         table = otTables.MultipleSubst()
         table.Format = 1
         for name, attrs, content in parseXML(
-                '<Coverage Format="1">'
+                '<Coverage>'
                 '  <Glyph value="o"/>'
                 '  <Glyph value="l"/>'
                 '</Coverage>'
@@ -599,7 +598,6 @@ def test_splitMarkBasePos():
 	glyphMap = {g: i for i, g in enumerate(glyphOrder)}
 
 	oldSubTable = buildMarkBasePosSubtable(marks, bases, glyphMap)
-	oldSubTable.MarkCoverage.Format = oldSubTable.BaseCoverage.Format = 1
 	newSubTable = otTables.MarkBasePos()
 
 	ok = otTables.splitMarkBasePos(oldSubTable, newSubTable, overflowRecord=None)
@@ -608,11 +606,11 @@ def test_splitMarkBasePos():
 
 	assert getXML(oldSubTable.toXML) == [
 		'<MarkBasePos Format="1">',
-		'  <MarkCoverage Format="1">',
+		'  <MarkCoverage>',
 		'    <Glyph value="acutecomb"/>',
 		'    <Glyph value="gravecomb"/>',
 		'  </MarkCoverage>',
-		'  <BaseCoverage Format="1">',
+		'  <BaseCoverage>',
 		'    <Glyph value="a"/>',
 		'    <Glyph value="c"/>',
 		'  </BaseCoverage>',
@@ -654,10 +652,10 @@ def test_splitMarkBasePos():
 
 	assert getXML(newSubTable.toXML) == [
 		'<MarkBasePos Format="1">',
-		'  <MarkCoverage Format="1">',
+		'  <MarkCoverage>',
 		'    <Glyph value="cedillacomb"/>',
 		'  </MarkCoverage>',
-		'  <BaseCoverage Format="1">',
+		'  <BaseCoverage>',
 		'    <Glyph value="a"/>',
 		'    <Glyph value="c"/>',
 		'  </BaseCoverage>',
